#!/bin/bash

set -e
set -x

P=rasterio
V=1.1.8
B=1

export GDAL_VERSION=3.1

[ -d "$OSGEO4W_REP" ] || { echo repository not set; exit 1; }
[ -f $P-$V.tar.gz ] || wget https://files.pythonhosted.org/packages/73/2d/3e1bc56d75bf7c4cd5df51536992b3420197f2aa5ddd4d93e12100715dff/rasterio-1.1.8.tar.gz
[ -f ../PKG-INFO ] || tar -C .. -xzf $P-$V.tar.gz --xform s,^$P-$V,.,

export PYTHON=Python37
export OSGEO4W_MAINTAINER=JuergenFischer

# override msys
cat() { /bin/cat "$@"; }
cp() { /bin/cp "$@"; }
rm() { /bin/rm "$@"; }
mkdir() { /bin/mkdir "$@"; }
tar() { /bin/tar "$@"; }
ls() { /bin/ls "$@"; }
sed() { /bin/sed "$@"; }
diff() { /bin/diff "$@"; }
find() { /bin/find "$@"; }
xargs() { /bin/xargs "$@"; }
declare -x cat cp rm mkdir tar ls sed diff

#
# run batch file and source environment changes
#
fetchenv() {
	local IFS
	IFS=
	batch=$1	
	shift
	srcenv=$(mktemp /tmp/srcenv.XXXXXXXXXX)
	dstenv=$(mktemp /tmp/dstenv.XXXXXXXXXX)
	diffenv=$(mktemp /tmp/diffenv.XXXXXXXXXX)
	cmd /c set >$srcenv
	cmd /c call `cygpath -w $batch` "$@" \>nul 2\>nul \& set >$dstenv
	diff -u $srcenv $dstenv | sed -f $D/envdiff.sed >$diffenv
	. $diffenv
	PATH=$PATH:/bin:/usr/bin:/cygdrive/c/windows32/system32:/cygdrive/c/windows
	rm -f $srcenv $dstenv $diffenv
}

for ARCH in x86 x86_64; do
	export ARCH

	(
		case "$ARCH" in
		x86)
			export OSGEO4W_ROOT=/c/OSGeo4W
			;;

		x86_64)
			export OSGEO4W_ROOT=/c/OSGeo4W64
			;;

		*)
			echo "Unsupported arch $ARCH" >&2
			exit 1
			;;
		esac

		[ -z "$ROOT" ] && ROOT=/d/src/osgeo4w64

		export D=$PWD
		fetchenv $OSGEO4W_ROOT/bin/o4w_env.bat
		fetchenv $OSGEO4W_ROOT/bin/py3_env.bat

		cd ..
		python setup.py build_ext -I$(cygpath -aw $OSGEO4W_ROOT/include) -lgdal_i -L$(cygpath -aw $OSGEO4W_ROOT/lib)
		python setup.py install --no-compile --prefix osgeo4w/install-$ARCH/apps/$PYTHON --record osgeo4w/record-$ARCH.txt --single-version-externally-managed

		cd osgeo4w
		mkdir -p $OSGEO4W_REP/$ARCH/release/python3/python3-$P
		tar       -cjf $OSGEO4W_REP/$ARCH/release/python3/python3-$P/python3-$P-$V-$B.tar.bz2 --xform "s,^install-$ARCH/,," install-$ARCH/apps/Python*
		tar -C .. -cjf $OSGEO4W_REP/$ARCH/release/python3/python3-$P/python3-$P-$V-$B-src.tar.bz2 osgeo4w/package.sh osgeo4w/envdiff.sed

		cat >$OSGEO4W_REP/$ARCH/release/python3/python3-$P/setup.hint <<EOF
sdesc: "Fast and direct raster I/O for use with Numpy and SciPy"
ldesc: "Fast and direct raster I/O for use with Numpy and SciPy"
maintainer: $MAINTAINER
category: Libs
requires: python3-core gdal python3-affine python3-attrs python3-click python3-cligj python3-numpy python3-snuggs python3-click-plugins
EOF
	)
done
